/// <reference types="node" />
import { inspect, InspectOptions } from "util";
import V1 from "../V1";
export declare class CreateReferralConversionRequest {
    "referralAccountSid"?: string;
}
/**
 * Options to pass to create a ReferralConversionInstance
 */
export interface ReferralConversionContextCreateOptions {
    /**  */
    createReferralConversionRequest: CreateReferralConversionRequest;
}
export interface ReferralConversionContext {
    /**
     * Create a ReferralConversionInstance
     *
     * @param params - Body for request
     * @param callback - Callback to handle processed record
     *
     * @returns Resolves to processed ReferralConversionInstance
     */
    create(params: CreateReferralConversionRequest, callback?: (error: Error | null, item?: ReferralConversionInstance) => any): Promise<ReferralConversionInstance>;
    /**
     * Provide a user-friendly representation
     */
    toJSON(): any;
    [inspect.custom](_depth: any, options: InspectOptions): any;
}
export interface ReferralConversionContextSolution {
}
export declare class ReferralConversionContextImpl implements ReferralConversionContext {
    protected _version: V1;
    protected _solution: ReferralConversionContextSolution;
    protected _uri: string;
    constructor(_version: V1);
    create(params: CreateReferralConversionRequest, callback?: (error: Error | null, item?: ReferralConversionInstance) => any): Promise<ReferralConversionInstance>;
    /**
     * Provide a user-friendly representation
     *
     * @returns Object
     */
    toJSON(): ReferralConversionContextSolution;
    [inspect.custom](_depth: any, options: InspectOptions): string;
}
interface ReferralConversionResource {
    converted_account_sid: string;
}
export declare class ReferralConversionInstance {
    protected _version: V1;
    protected _solution: ReferralConversionContextSolution;
    protected _context?: ReferralConversionContext;
    constructor(_version: V1, payload: ReferralConversionResource);
    convertedAccountSid: string;
    private get _proxy();
    /**
     * Create a ReferralConversionInstance
     *
     * @param params - Body for request
     * @param callback - Callback to handle processed record
     *
     * @returns Resolves to processed ReferralConversionInstance
     */
    create(params: CreateReferralConversionRequest, callback?: (error: Error | null, item?: ReferralConversionInstance) => any): Promise<ReferralConversionInstance>;
    /**
     * Provide a user-friendly representation
     *
     * @returns Object
     */
    toJSON(): {
        convertedAccountSid: string;
    };
    [inspect.custom](_depth: any, options: InspectOptions): string;
}
export interface ReferralConversionSolution {
}
export interface ReferralConversionListInstance {
    _version: V1;
    _solution: ReferralConversionSolution;
    _uri: string;
    (): ReferralConversionContext;
    get(): ReferralConversionContext;
    /**
     * Provide a user-friendly representation
     */
    toJSON(): any;
    [inspect.custom](_depth: any, options: InspectOptions): any;
}
export declare function ReferralConversionListInstance(version: V1): ReferralConversionListInstance;
export {};
